<?php

set_include_path(get_include_path() . PATH_SEPARATOR .  dirname(__FILE__) . '/libraries');
include_once('Zend/Pdf.php');
include_once('src/defs.php');
include_once('src/api.php');
include_once('src/lib.php');

if (!defined('_PS_VERSION_')) exit;
define('_PATRONBROKER_TPL_DIR_', dirname(__FILE__).'/views/templates/');
define('_PATRONBROKER_URI_', _MODULE_DIR_.'patronbroker/');
define('_PATRONBROKER_JS_URI_', _PATRONBROKER_URI_.'views/js/');
define('_PATRONBROKER_IMG_URI_', _PATRONBROKER_URI_.'views/img/');
define('_PATRONBROKER_PDF_URI_', _PATRONBROKER_URI_.'pdf.php');
define('_PATRONBROKER_AJAX_URI_', _PATRONBROKER_URI_.'ajax.php');

define('psb_debug', 1);

class Patronbroker extends CarrierModule {
	public $module_url;
	public static $errors = array();
	public $id_carrier;
	const PATRONBROKER_UBEZ = 'PATRONBROKER_UBEZ';
	const PATRONBROKER_WAGA = 'PATRONBROKER_WAGA';
	const PATRONBROKER_DLUG = 'PATRONBROKER_DLUG';
	const PATRONBROKER_SZER = 'PATRONBROKER_SZER';
	const PATRONBROKER_WYS = 'PATRONBROKER_WYS';
	const upd_from = 4;
	const upd_to = 5; 
	
	public function __construct() {
    	$this->name = 'patronbroker';
    	$this->tab = 'shipping_logistics';
    	$this->version = '1.1';
    	$this->author = 'Marcin Bogdanski @ Opennet';
    	$this->need_instance = 1;
    	$this->ps_versions_compliancy = array('min' => '1.6', 'max' => '1.7'); 
    	$this->bootstrap = true;
 
 		parent::__construct();
 
    	$this->displayName = $this->l('Patron Broker');
    	$this->description = $this->l('Patron Broker carriers');
    	$this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
 
 		$warns = array();
    	if(Configuration::get('PATRONBROKER_API_URL') == psb_testurl) $warns[] = 'Konfiguracja demonstracyjna - ustaw dane do API zgodnie z umową z Patron';
    	if(!extension_loaded('soap')) $warns[] = 'Brak modułu php soap niezbędnego do działania wtyczki';
		if (version_compare(PHP_VERSION, '5.3.6', '<')) $warns[] = 'Zalecana wersja PHP przynajmniej 5.3.6';

		$aconf = dirname(__FILE__) . '/ajax_conf.php';
		if(!file_exists($aconf)) {
			file_put_contents($aconf, '<?php define("_PS_ADMIN_DIR_", "' . getcwd() . '"); ?>');
			if(!file_exists($aconf)) $warns[] = sprintf($this->l('Wystąpił błąd tworzenia pliku konfiguracyjnego w katalogu %s. Odblokuj prawa zapisu'), dirname(__FILE__));
		}
		
		if (count ( $warns ) > 0) {
			array_unshift($warns, $this->l('Skonfiguruj poprawnie dostęp do API'));
			if(version_compare(_PS_VERSION_, '1.7.0.0', '>=')) $this->warning = join ( '. ', $warns ) . '.';
			else $this->warning = '<ul><li>' . join ( '</li><li>', $warns ) . '</li></ul>';
		}
		PsbLib::$module_instance = &$this;
		PsbApi::$module_instance = &$this;
	}

	public function install() {
		if(!parent::install() || !$this->registerHook('adminOrder') || !$this->registerHook('paymentTop') || !$this->registerHook('updateCarrier')) return false;
		if(!PsbLib::createTables()) return false;
		if(!PsbLib::installTab()) return false;
		if(!PsbLib::createConfig()) return false;
		
		return true;
	}

	public function uninstall() {
		if (! parent::uninstall ())
			return false;
		if (! PsbLib::uninstallTab ())
			return false;
		if (! PsbLib::deleteAllCarriers())
			return false;
		return true;
	}
	
	public function getOrderShippingCost($params, $shipping_cost) {
//		if(!PsbLib::testConfig()) return false;
		if (Configuration::get ( 'PATRONBROKER_RANGES' ))
			return $shipping_cost;
		return $this->getOrderShippingCostExternal ( $params );
	}
	
	public function getOrderShippingCostExternal($params) {
//		if(!PsbLib::testConfig()) return false;
		$cena = null;
		$a = PsbLib::getSymById($this->id_carrier);
		if($a == null) return false;
		list($sym, $cod, $carr) = $a;
		$pt = unserialize( Configuration::get ( 'PATRONBROKER_PRICE' ) );
		$cena = $pt[$sym][$cod ? 1 : 0];
		if ($cena == null)
			$cena = $cod ? defCodPrice : defPrice;
		if ($cena == 0)
			$cena = false;
		return $cena;
	}

	public function hookUpdateCarrier($params) {
		$id_carrier_old = (int)($params['id_carrier']);
		$id_carrier_new = (int)($params['carrier']->id);
		$a = PsbLib::getSymById( $id_carrier_old );
		if($a == null) return false;
		list($sym, $cod, $carr) = $a;
	
		$arch = unserialize( Configuration::getGlobalValue ( 'PATRONBROKER_SERVARCH' ) );
		$arch[$id_carrier_old] = array('sym' => $sym, 'cod' => $cod, 'id' => $id_carrier_old, 'carr' => $carr);
		Configuration::updateGlobalValue ( 'PATRONBROKER_SERVARCH', serialize ( $arch ) );
	
		$t = unserialize( Configuration::getGlobalValue ( 'PATRONBROKER_SERV' ) );
		if($cod) $t[$sym]['id_cod'] = $id_carrier_new;
		else $t[$sym]['id'] = $id_carrier_new;
		Configuration::updateGlobalValue ( 'PATRONBROKER_SERV', serialize ( $t ) );
	}
	
	public function getContent() {
    	$output = null;
 
    	if (Tools::isSubmit('submit'.$this->name)) {
        	$login = strval(Tools::getValue('PATRONBROKER_API_LOGIN'));
        	if (!$login || empty($login) || !Validate::isGenericName($login)) $output .= $this->displayError($this->l('Nieprawidłowy login'));
        	else Configuration::updateValue('PATRONBROKER_API_LOGIN', $login);

        	$pass = strval(Tools::getValue('PATRONBROKER_API_PASS'));
        	if (!$pass || empty($pass)) $output .= $this->displayError($this->l('Nieprawidłowe hasło'));
        	else Configuration::updateValue('PATRONBROKER_API_PASS', $pass);

        	$url = strval(Tools::getValue('PATRONBROKER_API_URL'));
        	if (!$url || empty($url)) $output .= $this->displayError($this->l('Nieprawidłowy adres API'));
        	else Configuration::updateValue('PATRONBROKER_API_URL', $url);

        	Configuration::updateValue('PATRONBROKER_RANGES', strval(Tools::getValue('PATRONBROKER_RANGES_on')));
        	Configuration::updateValue ( 'PATRONBROKER_PRICE', serialize(Tools::getValue ( 'PATRONBROKER_PRICE' )) );
        	 
        	$ubez = strval(Tools::getValue('PATRONBROKER_UBEZ'));
        	if (!is_numeric($ubez) || ($ubez < 0)) $output .= $this->displayError($this->l('Nieprawidłowa kwota ubezpieczenia'));
        	else Configuration::updateValue('PATRONBROKER_UBEZ', $ubez);

        	$waga = strval(Tools::getValue('PATRONBROKER_WAGA'));
        	if (!is_numeric($waga) || ($waga < 0)) $output .= $this->displayError($this->l('Nieprawidłowa waga'));
        	else Configuration::updateValue('PATRONBROKER_WAGA', $waga);

        	$dlug = strval(Tools::getValue('PATRONBROKER_DLUG'));
        	if (!is_numeric($dlug) || ($dlug < 0)) $output .= $this->displayError($this->l('Nieprawidłowa długość'));
        	else Configuration::updateValue('PATRONBROKER_DLUG', $dlug);

        	$szer = strval(Tools::getValue('PATRONBROKER_SZER'));
        	if (!is_numeric($szer) || ($szer < 0)) $output .= $this->displayError($this->l('Nieprawidłowa szerokość'));
        	else Configuration::updateValue('PATRONBROKER_SZER', $szer);

        	$wys = strval(Tools::getValue('PATRONBROKER_WYS'));
        	if (!is_numeric($wys) || ($wys < 0)) $output .= $this->displayError($this->l('Nieprawidłowa wysokość'));
        	else Configuration::updateValue('PATRONBROKER_WYS', $wys);

        	Configuration::updateValue('PATRONBROKER_REQ_REF', strval(Tools::getValue('PATRONBROKER_REQ_REF_on')));
        	Configuration::updateValue('PATRONBROKER_REQ_SMS', strval(Tools::getValue('PATRONBROKER_REQ_SMS_on')));
        	Configuration::updateValue('PATRONBROKER_REQ_MAIL', strval(Tools::getValue('PATRONBROKER_REQ_MAIL_on')));
        	Configuration::updateValue('PATRONBROKER_NST', strval(Tools::getValue('PATRONBROKER_NST_on')));
        	Configuration::updateValue('PATRONBROKER_ZAW', strval(Tools::getValue('PATRONBROKER_ZAW_on')));
        	Configuration::updateValue('PATRONBROKER_MPACK', strval(Tools::getValue('PATRONBROKER_MPACK_on')));
        	Configuration::updateValue('PATRONBROKER_NAD_NAZ', strval(Tools::getValue('PATRONBROKER_NAD_NAZ')));
        	Configuration::updateValue('PATRONBROKER_NAD_ADR', strval(Tools::getValue('PATRONBROKER_NAD_ADR')));
        	Configuration::updateValue('PATRONBROKER_NAD_MIASTO', strval(Tools::getValue('PATRONBROKER_NAD_MIASTO')));
        	Configuration::updateValue('PATRONBROKER_NAD_KOD', strval(Tools::getValue('PATRONBROKER_NAD_KOD')));
        	Configuration::updateValue('PATRONBROKER_NAD_OSOBA', strval(Tools::getValue('PATRONBROKER_NAD_OSOBA')));
        	Configuration::updateValue('PATRONBROKER_NAD_TEL', strval(Tools::getValue('PATRONBROKER_NAD_TEL')));
        	Configuration::updateValue('PATRONBROKER_NAD_EMAIL', strval(Tools::getValue('PATRONBROKER_NAD_EMAIL')));
    	}
    	return $output.$this->displayForm();
   	}
	
	public function displayForm()
{
    // Get default language
    $default_lang = (int)Configuration::get('PS_LANG_DEFAULT');
     
    $nname = 'name';
    //if($lang == 'en') $nname = 'name_en';
    $tserv = unserialize( Configuration::getGlobalValue ( 'PATRONBROKER_SERV' ) );
    
    // Init Fields form array
    $fields_form[0]['form'] = array(
        'legend' => array(
            'title' => $this->l('Settings'),
        ),
        'input' => array(
            array(
                'type' => 'text',
                'label' => 'Patronbroker API - login',
                'name' => 'PATRONBROKER_API_LOGIN',
                'size' => 20,
                'required' => true
            ),
            array(
                'type' => 'password',
                'label' => 'Patronbroker API - hasło',
                'name' => 'PATRONBROKER_API_PASS',
                'size' => 20,
                'required' => true
            ),
            array(
                'type' => 'text',
                'label' => 'Patronbroker API - url',
                'name' => 'PATRONBROKER_API_URL',
                'size' => 200,
                'required' => true,
                'desc' => 'Po uzyskaniu z Patron Broker Service loginu i hasła zmień url na ' . psb_produrl
            ),
        	array (
        		'label' => '',
        		'name' => 'PATRONBROKER_API_ACTIONS',
        		'ajax_uri' => _PATRONBROKER_AJAX_URI_,
        		'token' => sha1 ( _COOKIE_KEY_ . $this->name ),
        		'group' => $this->context->shop->getContextShopGroupID(),
        		'shop' => $this->context->shop->getContextShopID(),
        		'type' => ''
        	),
        	array(
            	'type' => 'checkbox',
                'name' => 'PATRONBROKER_RANGES',
                'values' => array(
                	'query' => array(
                    	array(
                        	'id' => 'on',
                            'name' => 'Ceny w/g przedziałów',
                            'val' => '1'
                        ),
                    ),
               		'id' => 'id',
                	'name' => 'name'
          		)
            ),
        	array (
        		'label' => '',
        		'name' => 'PATRONBROKER_PRICE',
        		'serv' => $tserv,
        		'field' => $nname,
        		'type' => ''
        	),
        		array(
                'type' => 'text',
                'label' => 'Domyślna kwota ubezpieczenia',
                'name' => 'PATRONBROKER_UBEZ',
                'size' => 50,
                'required' => true
            ),
            array(
                'type' => 'text',
                'label' => 'Domyślna waga (kg)',
                'name' => 'PATRONBROKER_WAGA',
                'size' => 50,
                'required' => true
            ),
            array(
                'type' => 'text',
                'label' => 'Domyślna wysokość (cm)',
                'name' => 'PATRONBROKER_WYS',
                'size' => 50,
                'required' => true
            ),
            array(
                'type' => 'text',
                'label' => 'Domyślna długość (cm)',
                'name' => 'PATRONBROKER_DLUG',
                'size' => 50,
                'required' => true
            ),
            array(
                'type' => 'text',
                'label' => 'Domyślna szerokość (cm)',
                'name' => 'PATRONBROKER_SZER',
                'size' => 50,
                'required' => true
            ),
            array(
            	'type' => 'checkbox',
                'name' => 'PATRONBROKER_REQ_REF',
                'values' => array(
                	'query' => array(
                    	array(
                        	'id' => 'on',
                            'name' => 'Drukować numer zamówienia na etykiecie',
                            'val' => '1'
                        ),
                    ),
               		'id' => 'id',
                	'name' => 'name'
          		)
            ),
            array(
            	'type' => 'checkbox',
                'name' => 'PATRONBROKER_REQ_SMS',
                'values' => array(
                	'query' => array(
                    	array(
                        	'id' => 'on',
                            'name' => 'Powiadomienie SMS',
                            'val' => '1'
                        ),
                    ),
               		'id' => 'id',
                	'name' => 'name'
          		)
            ),
            array(
            	'type' => 'checkbox',
                'name' => 'PATRONBROKER_REQ_MAIL',
                'values' => array(
                	'query' => array(
                    	array(
                        	'id' => 'on',
                            'name' => 'Powiadomienie e-mail',
                            'val' => '1'
                        ),
                    ),
               		'id' => 'id',
                	'name' => 'name'
          		)
            ),
            array(
            	'type' => 'checkbox',
                'name' => 'PATRONBROKER_NST',
                'values' => array(
                	'query' => array(
                    	array(
                        	'id' => 'on',
                            'name' => 'Domyślnie włączony NST',
                            'val' => '1'
                        ),
                    ),
               		'id' => 'id',
                	'name' => 'name'
          		)
            ),
        	array(
            	'type' => 'checkbox',
                'name' => 'PATRONBROKER_ZAW',
                'values' => array(
                	'query' => array(
                    	array(
                        	'id' => 'on',
                            'name' => 'Drukowanie zawartości w polu uwagi',
                            'val' => '1'
                        ),
                    ),
               		'id' => 'id',
                	'name' => 'name'
          		)
            ),
        	array(
        		'type' => 'checkbox',
   				'name' => 'PATRONBROKER_MPACK',
   				'values' => array(
					'query' => array(
    					array(
        					'id' => 'on',
        					'name' => 'Obsługa etykiet wielopaczkowych',
        					'val' => '1'
        				),
        			),
        			'id' => 'id',
        			'name' => 'name'
        		)
        	),
        	array(
                'type' => 'text',
                'label' => 'Nazwa nadawcy',
                'name' => 'PATRONBROKER_NAD_NAZ',
                'size' => 40,
                'required' => false
            ),
            array(
                'type' => 'text',
                'label' => 'Adres nadawcy',
                'name' => 'PATRONBROKER_NAD_ADR',
                'size' => 120,
                'required' => false
            ),
            array(
                'type' => 'text',
                'label' => 'Miasto',
                'name' => 'PATRONBROKER_NAD_MIASTO',
                'size' => 20,
                'required' => false
            ),
            array(
                'type' => 'text',
                'label' => 'Kod pocztowy',
                'name' => 'PATRONBROKER_NAD_KOD',
                'size' => 8,
                'required' => false
            ),
            array(
                'type' => 'text',
                'label' => 'Osoba',
                'name' => 'PATRONBROKER_NAD_OSOBA',
                'size' => 40,
                'required' => false
            ),
            array(
                'type' => 'text',
                'label' => 'Telefon',
                'name' => 'PATRONBROKER_NAD_TEL',
                'size' => 20,
                'required' => false
            ),
            array(
                'type' => 'text',
                'label' => 'Email',
                'name' => 'PATRONBROKER_NAD_EMAIL',
                'size' => 40,
                'required' => false
            ),
        ),
        'submit' => array(
            'title' => $this->l('Save'),
            'class' => 'button'
        )
    );
     
    $helper = new HelperForm();
     
    // Module, token and currentIndex
    $helper->module = $this;
    $helper->name_controller = $this->name;
    $helper->token = Tools::getAdminTokenLite('AdminModules');
    $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;
     
    // Language
    $helper->default_form_language = $default_lang;
    $helper->allow_employee_form_lang = $default_lang;
     
    // Title and toolbar
    $helper->title = $this->displayName;
    $helper->show_toolbar = true;        // false -> remove toolbar
    $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
    $helper->submit_action = 'submit'.$this->name;
    $helper->toolbar_btn = array(
        'save' =>
        array(
            'desc' => $this->l('Save'),
            'href' => AdminController::$currentIndex.'&configure='.$this->name.'&save'.$this->name.
            '&token='.Tools::getAdminTokenLite('AdminModules'),
        ),
        'back' => array(
            'href' => AdminController::$currentIndex.'&token='.Tools::getAdminTokenLite('AdminModules'),
            'desc' => $this->l('Back to list')
        )
    );
     
    // Load current value
    $helper->fields_value['PATRONBROKER_API_LOGIN'] = Configuration::get('PATRONBROKER_API_LOGIN');
    $helper->fields_value['PATRONBROKER_API_PASS'] = Configuration::get('PATRONBROKER_API_PASS');
    $helper->fields_value['PATRONBROKER_API_URL'] = Configuration::get('PATRONBROKER_API_URL');
    $helper->fields_value['PATRONBROKER_RANGES_on'] = Configuration::get('PATRONBROKER_RANGES');
    $t1 = unserialize(Configuration::get ( 'PATRONBROKER_PRICE' ));
    $t2 = array();
    if(is_array($t1))
    	foreach ($t1 as $k => $r)
    		if(isset($tserv[$k]['name']))
    			$t2[$k] = $r;
    $helper->fields_value ['PATRONBROKER_PRICE'] = $t2;
    $helper->fields_value['PATRONBROKER_UBEZ'] = Configuration::get('PATRONBROKER_UBEZ');
    $helper->fields_value['PATRONBROKER_WAGA'] = Configuration::get('PATRONBROKER_WAGA');
    $helper->fields_value['PATRONBROKER_WYS'] = Configuration::get('PATRONBROKER_WYS');
    $helper->fields_value['PATRONBROKER_DLUG'] = Configuration::get('PATRONBROKER_DLUG');
    $helper->fields_value['PATRONBROKER_SZER'] = Configuration::get('PATRONBROKER_SZER');
    $helper->fields_value['PATRONBROKER_REQ_REF_on'] = Configuration::get('PATRONBROKER_REQ_REF');
    $helper->fields_value['PATRONBROKER_REQ_SMS_on'] = Configuration::get('PATRONBROKER_REQ_SMS');
    $helper->fields_value['PATRONBROKER_REQ_MAIL_on'] = Configuration::get('PATRONBROKER_REQ_MAIL');
    $helper->fields_value['PATRONBROKER_NST_on'] = Configuration::get('PATRONBROKER_NST');
//    $helper->fields_value['PATRONBROKER_WP_on'] = Configuration::get('PATRONBROKER_WP');
    $helper->fields_value['PATRONBROKER_ZAW_on'] = Configuration::get('PATRONBROKER_ZAW');
//    $helper->fields_value['PATRONBROKER_NBUFOR_on'] = Configuration::get('PATRONBROKER_NBUFOR');
    $helper->fields_value['PATRONBROKER_MPACK_on'] = Configuration::get('PATRONBROKER_MPACK');
    $helper->fields_value['PATRONBROKER_NAD_NAZ'] = Configuration::get('PATRONBROKER_NAD_NAZ');
    $helper->fields_value['PATRONBROKER_NAD_ADR'] = Configuration::get('PATRONBROKER_NAD_ADR');
    $helper->fields_value['PATRONBROKER_NAD_MIASTO'] = Configuration::get('PATRONBROKER_NAD_MIASTO');
    $helper->fields_value['PATRONBROKER_NAD_KOD'] = Configuration::get('PATRONBROKER_NAD_KOD');
    $helper->fields_value['PATRONBROKER_NAD_OSOBA'] = Configuration::get('PATRONBROKER_NAD_OSOBA');
    $helper->fields_value['PATRONBROKER_NAD_TEL'] = Configuration::get('PATRONBROKER_NAD_TEL');
    $helper->fields_value['PATRONBROKER_NAD_EMAIL'] = Configuration::get('PATRONBROKER_NAD_EMAIL');
     
    return $helper->generateForm($fields_form);
}

	public function hookAdminOrder($params) {
		$order = new Order ( ( int ) $params ['id_order'] );
		$carrier = new Carrier ( ( int ) $order->id_carrier );
		$a = PsbLib::getSymById( $order->id_carrier );
		if($a == null) return '';
		
		$address_r = new Address($order->id_address_delivery);
		$order_carrier = new OrderCarrier((int)$order->getIdOrderCarrier());
		$pobranie = PsbLib::getCOD($order);
		$aprod = $order->getProducts();

		$waga = $order_carrier->weight;
		$wys = 0;
		$szer = 0;
		$dlug = 0;
		if(count($aprod) == 1) {
			$prod = array_pop($aprod);
			$wys = $prod['height'];
			$szer = $prod['depth'];
			$dlug = $prod['width'];
		}
		
		if($waga <= 0) $waga = PsbLib::getConf('PATRONBROKER_WAGA', $order);
		if($wys <= 0) $wys = PsbLib::getConf('PATRONBROKER_WYS', $order);
		if($szer <= 0) $szer = PsbLib::getConf('PATRONBROKER_SZER', $order);
		if($dlug <= 0) $dlug = PsbLib::getConf('PATRONBROKER_DLUG', $order);
		if($waga <= 0) $waga = psb_defW;
		if($wys <= 0) $wys = psb_defH;
		if($szer <= 0) $szer = psb_defD;
		if($dlug <= 0) $dlug = psb_defL;
		$ubez = PsbLib::getConf('PATRONBROKER_UBEZ', $order);
		$nst = PsbLib::getConf('PATRONBROKER_NST', $order) ? "checked" : "";
		$waga = round($waga, 2);

//		$customer = new Customer((int)$order->id_customer);
		$this->context->controller->addJqueryUI(array(
			'ui.core',
			'ui.widget',
			'ui.accordion'
			));

			$this->context->controller->addJqueryPlugin('scrollTo');
			$this->context->controller->addJS(_PATRONBROKER_JS_URI_.'adminOrder.js');
			$id_label = PsbLib::getLabelByOrder((int)$params['id_order']);
			if(!$id_label) $id_label = '';
			$this->context->smarty->assign(array(
				'order' => $order,
				'patronbroker_ajax_uri' => _PATRONBROKER_AJAX_URI_,
				'patronbroker_token' => sha1(_COOKIE_KEY_.$this->name),
				'patronbroker_id_label' => $id_label,
				'patronbroker_kwota' => $pobranie,
				'patronbroker_adres' => $address_r->address1 . ($address_r->address2 != '' ? (' ' . $address_r->address2) : ''),
				'patronbroker_kod' => trim($address_r->postcode),
				'patronbroker_miasto' => $address_r->city,
				'patronbroker_uwagi' => PsbLib::genUwagi($order),
				'patronbroker_ubez' => $ubez,
				'patronbroker_waga' => $waga,
				'patronbroker_szer' => $szer,
				'patronbroker_dlug' => $dlug,
				'patronbroker_wys' => $wys,
				'patronbroker_nst' => $nst,
				'patronbroker_track_url' => PsbLib::genTrackLink(PsbLib::getTrackByOrder((int)$params['id_order']))
			));
		if(PsbLib::getConf('PATRONBROKER_MPACK', $order)) {
			return $this->context->smarty->fetch(_PATRONBROKER_TPL_DIR_.'admin/adminOrderMpack.tpl');
		}
		else {
			return $this->context->smarty->fetch(_PATRONBROKER_TPL_DIR_.'admin/adminOrder.tpl');
		}
	}

	public function hookPaymentTop($params) {
		if (! Validate::isLoadedObject ( $this->context->cart ) || ! $this->context->cart->id_carrier)
			return;
			$id_carrier = $this->context->cart->id_carrier;
	
			$a = PsbLib::getSymById( $id_carrier );
			if($a == null) return;
			list($sym, $is_cm_cod, $carr) = $a;
	
			$cache_id = 'exceptionsCache';
			$exceptionsCache = (Cache::isStored ( $cache_id )) ? Cache::retrieve ( $cache_id ) : array ();
			$controller = (Configuration::get ( 'PS_ORDER_PROCESS_TYPE' ) == 0) ? 'order' : 'orderopc';
			$id_hook = Hook::getIdByName ( 'displayPayment' );
	
			if ($paymentModules = Module::getPaymentModules ()) {
				foreach ( $paymentModules as $mod ) {
					$is_pm_cod = (($mod ['name'] == 'cashondelivery') || ($mod ['name'] == 'ps_cashondelivery'));
					if ($is_cm_cod ^ $is_pm_cod) {
						$key = ( int ) $id_hook . '-' . ( int ) $mod ['id_module'];
						$exceptionsCache [$key] [$this->context->shop->id] [] = $controller;
					}
				}
				Cache::store ( $cache_id, $exceptionsCache );
			}
	}

}

?>
